![banner](/docs/source/_static/banner.svg)

**dpeeg** provides a complete workflow for deep learning decoding EEG tasks, 
including basic datasets (datasets can be easily customized), basic network 
models, model training, rich experiments, and detailed experimental result 
storage.

# Usage

1. Create a new virtual environment named "dpeeg" with 
[Python](https://www.python.org/) >= 3.10 using Anaconda3 and activate it：
```Shell
conda create --name dpeeg python
conda activate dpeeg
```

2. dpeeg depends on [Pytorch](https://pytorch.org/). Please refer to the 
corresponding official website for installation.

3. Complete the installation via `pip`:
```Shell
pip install dpeeg
``` 